FRAGMENT_DOCUMENT_MAP = {}  # TODO: THAT NEEDS TO DIE
ENUM_CLASS_MAP = {}  # TODO: THAT NEEDS TO DIE
INPUTTYPE_CLASS_MAP = {}
FRAGMENT_CLASS_MAP = {}


SCALAR_DEFAULTS = {
    "ID": "str",
    "String": "str",
    "Int": "int",
    "Boolean": "bool",
    "GenericScalar": "Dict",
    "DateTime": "str",
    "Float": "float",
}
